@@ -6,7 +6,7 @@ from nonebot.adapters.onebot.v11 import Message, MessageSegment
 from nonebot.params import Arg, CommandArg, ArgPlainText, RawCommand
 from .drawer import get_token, get_taskId, get_img
 
-drawer = on_command("画画", aliases={'油画', '水彩', '卡通', '粉笔画', '儿童画', '蜡笔画'}, priority=5)
+drawer = on_command("画画", aliases={'油画', '水彩画', '卡通画', '粉笔画', '儿童画', '蜡笔画'}, priority=5)
 
 
 @drawer.handle()
@@ -20,10 +20,11 @@ async def handle_first_receive(matcher: Matcher, command = RawCommand(), args =
         await matcher.finish(help_msg)
         
     else:
+        command_str = str(command)
         style = '油画' # 绘画时style默认为油画
-        style_list = ['油画', '水彩画', '卡通画', '粉笔画', '儿童画', '蜡笔画']
+        style_list = ['油画', '水彩', '卡通', '粉笔画', '儿童画', '蜡笔画']
         for keyword in style_list:
-            if keyword in command:
+            if keyword in command_str:
                 style = keyword
                 break  
         text = args
